@@ -4,11 +4,11 @@
 #  (C) Paul Evans, 2015-2021 -- leonerd@leonerd.org.uk
 
 use v5.26;
-use Object::Pad 0.43;  # ADJUST
+use Object::Pad 0.57;  # :does
 
-package Test::Device::Chip::Adapter 0.20;
+package Test::Device::Chip::Adapter 0.21;
 class Test::Device::Chip::Adapter
-   implements Device::Chip::Adapter;
+   :does(Device::Chip::Adapter);
 
 use Carp;
 
@@ -160,6 +160,7 @@ BEGIN {
                            [qw( SPI )] ],
    );
 
+   use Object::Pad ':experimental(mop)';
    my $meta = Object::Pad::MOP::Class->for_caller;
 
    foreach my $method ( keys %METHODS ) {
